@@ -1,5 +1,5 @@
 package MooseX::NonMoose::Meta::Role::Class;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Moose::Role;
 
@@ -9,7 +9,7 @@ MooseX::NonMoose::Meta::Role::Class - metaclass trait for L<MooseX::NonMoose>
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -124,7 +124,10 @@ around superclasses => sub {
         my $class = shift;
 
         my $params = $class->BUILDARGS(@_);
-        my $instance = $super_new->execute($class, @_);
+        my @foreign_params = $class->can('FOREIGNBUILDARGS')
+                           ? $class->FOREIGNBUILDARGS(@_)
+                           : @_;
+        my $instance = $super_new->execute($class, @foreign_params);
         my $self = Class::MOP::Class->initialize($class)->new_object(
             __INSTANCE__ => $instance,
             %$params,
