@@ -1,5 +1,5 @@
 package MooseX::NonMoose::Meta::Role::Constructor;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Moose::Role;
 
@@ -9,7 +9,7 @@ MooseX::NonMoose::Meta::Role::Constructor - constructor method trait for L<Moose
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -59,12 +59,16 @@ sub _generate_instance {
     my $self = shift;
     my ($var, $class_var) = @_;
     my $new = $self->name;
-    my $super_new_class = $self->associated_metaclass->find_next_method_by_name($new)->package_name;
+    my $meta = $self->associated_metaclass;
+    my $super_new_class = $meta->find_next_method_by_name($new)->package_name;
+    my $arglist = $meta->find_method_by_name('FOREIGNBUILDARGS')
+                ? "${class_var}->FOREIGNBUILDARGS(\@_)"
+                : '@_';
     # XXX: this should probably be taking something from the meta-instance api,
     # rather than calling bless directly, but this works fine for now, and i
     # want to wait for the whole immutablization stuff to settle down before
     # digging too deeply into it
-    "my $var = bless $super_new_class->$new(\@_), $class_var;\n";
+    "my $var = bless $super_new_class->$new($arglist), $class_var;\n";
 }
 
 no Moose::Role;
